#ifndef NT2_INCLUDE_FUNCTIONS_LDIV_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_LDIV_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/ldiv.hpp>

#endif
